﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web.Http;
using System.Web.Http.Cors;
using System.Web.Http.Description;
using System.Web.Http.Filters;
using System.Web.ModelBinding;
using UsingAngularJS.Models;
using UsingAngularJS.Repository;

namespace RESTfulService.Controllers
{

    [RoutePrefix("api")]
    [EnableCors(origins: "http://localhost:55129", headers: "*", methods: "*")]
    public class CustomersController : ApiController
    {

        ICustomerRepository _Repository;

        public CustomersController()
        {
            _Repository = new CustomerRepository();
        }

        // GET api/customers
        [ResponseType(typeof(IEnumerable<Customer>))]
        public IHttpActionResult Get()
        {
            var custs = _Repository.GetCustomers();
            if (custs == null)
            {
                return NotFound();
            }
            return Ok<IEnumerable<Customer>>(custs);
        }

        // GET api/customers/5
        [ResponseType(typeof(Customer))]
        public IHttpActionResult Get(int id)
        {
            var cust = _Repository.GetCustomer(id);
            if (cust == null)
            {
                return NotFound();
            }
            return Ok<Customer>(cust);
        }

        // POST api/customers
        //[ValidateModelState]
        public IHttpActionResult Post([FromBody]Customer cust)
        {
            if (ModelState.IsValid)
            {
                var newCust = _Repository.InsertCustomer(cust);
                if (newCust != null)
                {
                    return Created<Customer>(Request.RequestUri + newCust.ID.ToString(), newCust);
                }
                else
                {
                    return Conflict();
                }
            }

            return BadRequest(ModelState);
        }

        // PUT api/customers/5
        //Async example
        //[ValidateModelState]
        public async Task<IHttpActionResult> Put(int id, [FromBody]Customer cust)
        {
            if (ModelState.IsValid)
            {
                var status = _Repository.UpdateCustomer(cust);
                if (status)
                {
                    return Ok();
                }
            }
            return BadRequest(ModelState);
        }

        // DELETE api/customers/5
        public IHttpActionResult Delete(int id)
        {
            var status = _Repository.DeleteCustomer(id);
            if (status)
            {
                return Ok();
            }
            else
            {
                return NotFound();
            }
        }

        [HttpGet]
        [ResponseType(typeof(List<Order>))]
        [Route("customers/{custId:int}/orders")]
        public IHttpActionResult Orders(int custId)
        {
            var orders = _Repository.GetOrders(custId);
            if (orders == null)
            {
                return NotFound();
            }
            return Ok<List<Order>>(orders);
        }

        protected override void Dispose(bool disposing)
        {
            _Repository.Dispose();
            base.Dispose(disposing);
        }
    }
}